#!/usr/bin/perl
# greenflag2mapsonus.pl - Version 0.2  Feb 17, 2003 02:02

# This script converts routes generated by www.greenflag.com to a format 
# similar to the RAW output of www.mapsonus.com.  The intention of this script
# is entirely to allow the parsing program included in the Empeg application
# gpsapp (which was written specificly for the output of mapsonus) to work for
# directions made by greenflag.  The result is a route with turn waypoints, but
# no additional route shape points.  Until greenflag includes more waypoints, 
# this is all of the waypoint information available.

# To generate a route containing all of the information that is needed by this 
# script, make sure the Directions Style format is set to 'Step By Step Maps'
# The other options shouldn't matter, but if in doubt, use the defaults.

# This was written based on the HTML generated as of Febuary 17, 2003.  Any 
# changes made in the output of the directions from greenflag may cause
# this script to no longer generate correct output.  If this script doesn't 
# work, look for a more current version or learn Perl and change it yourself.

# Copyright 2003 by Colin Verne

# Usage greenflag2mapsonus.pl <input file>

if ($#ARGV != 0)
{
	print "Usage: $0 <input file>\n";
	exit
}

unless (open(FILE, "<$ARGV[0]"))
{
	print "Could not open $ARGV[0] for reading.";
	exit;
}

open(OUTFILE, ">$ARGV[0].tmp") or die "Can't open output file: $!";

my @lines = <FILE>;
my $turn = 0;
my $in_turn = 0;
my @route_points;

foreach $line (@lines)
{
	# try to match the lines containing maps of the turn points.
	if ($line =~ /^.*?MakeMap\.d\?S=938&amp;CT=.*?%3A.*?%3A.*?&amp;H=100&amp;IC=(.*?)3%3A(.*?)%3A100%3A.*?%3A(.*?)3%3A(.*?)%3A100%3A.*?%3A.*?\"100\" \/>(.*?)<\/td>.*?$/)
	{
		$lat = $1;
		$lon = $2;
		$last_lat = $3;
		$last_lon = $4;
		$desc = $5;
		print "Found line: $1 $2 $3 $4\n$5\n";
		
		# extract just the road
		if ($desc =~ /^.*?on <b>(.*?)<\/b>.*?$/)
		{
			$desc = $1;
		}
		else
		{
			#otherwise don't include the direction
			$desc = '';
		}
		
		# remove formatting tags
		#$dir =~ s/<.*?>//g;

	  print	"$desc\n---\n";
	  
		if ($turn == 0)
		{
			print OUTFILE "START $lon $lat {MARK.START} Start Point (Start)\n";
		}
		
		print OUTFILE "TURN $turn $lon $lat $turn 1 0 0 0 0.0 $desc\n";
		push(@route_points, "$lon $lat");
		$turn++;
	}
}

print OUTFILE "TURN $turn $lon $lat $turn 1 0 0 0 0.0 $desc\n";
print OUTFILE "END $last_lon $last_lat {MARK.END} End Point (Destination reached)\nMIN 0\n".join('  ', @route_points);

close OUTFILE;
